# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.ai.translate.v2 import translation_service_pb2 as yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/translate/v2/translation_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TranslationServiceStub(object):
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Translate = channel.unary_unary(
                '/yandex.cloud.ai.translate.v2.TranslationService/Translate',
                request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateResponse.FromString,
                _registered_method=True)
        self.DetectLanguage = channel.unary_unary(
                '/yandex.cloud.ai.translate.v2.TranslationService/DetectLanguage',
                request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageResponse.FromString,
                _registered_method=True)
        self.ListLanguages = channel.unary_unary(
                '/yandex.cloud.ai.translate.v2.TranslationService/ListLanguages',
                request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesResponse.FromString,
                _registered_method=True)


class TranslationServiceServicer(object):
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    def Translate(self, request, context):
        """Translates the text to the specified language.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetectLanguage(self, request, context):
        """Detects the language of the text.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLanguages(self, request, context):
        """Retrieves the list of supported languages.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TranslationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Translate': grpc.unary_unary_rpc_method_handler(
                    servicer.Translate,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateResponse.SerializeToString,
            ),
            'DetectLanguage': grpc.unary_unary_rpc_method_handler(
                    servicer.DetectLanguage,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageResponse.SerializeToString,
            ),
            'ListLanguages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLanguages,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.translate.v2.TranslationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.ai.translate.v2.TranslationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TranslationService(object):
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    @staticmethod
    def Translate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.translate.v2.TranslationService/Translate',
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DetectLanguage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.translate.v2.TranslationService/DetectLanguage',
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListLanguages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.translate.v2.TranslationService/ListLanguages',
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Federation(google.protobuf.message.Message):
    """A OIDC workload identity federation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    AUDIENCES_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    JWKS_URL_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Id of the OIDC workload identity federation."""
    name: builtins.str
    """Name of the OIDC workload identity federation
    The name is unique within the folder. 3-63 characters long.
    """
    folder_id: builtins.str
    """ID of the folder that the OIDC workload identity federation belongs to."""
    description: builtins.str
    """Description of the service account. 0-256 characters long."""
    enabled: builtins.bool
    """True - the OIDC workload identity federation is enabled and can be used for authentication.
    False - the OIDC workload identity federation is disabled and cannot be used for authentication.
    """
    issuer: builtins.str
    """URL of the external IdP server to be used for authentication."""
    jwks_url: builtins.str
    """URL reference to trusted keys in format of JSON Web Key Set."""
    @property
    def audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of trusted values for aud claim."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs"""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        folder_id: builtins.str = ...,
        description: builtins.str = ...,
        enabled: builtins.bool = ...,
        audiences: collections.abc.Iterable[builtins.str] | None = ...,
        issuer: builtins.str = ...,
        jwks_url: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audiences", b"audiences", "created_at", b"created_at", "description", b"description", "enabled", b"enabled", "folder_id", b"folder_id", "id", b"id", "issuer", b"issuer", "jwks_url", b"jwks_url", "labels", b"labels", "name", b"name"]) -> None: ...

global___Federation = Federation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ActivateDockerImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    DOCKER_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    docker_id: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        docker_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["docker_id", b"docker_id", "project_id", b"project_id"]) -> None: ...

global___ActivateDockerImageRequest = ActivateDockerImageRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class KMSKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of KMS symmetric key"""
    version_id: builtins.str
    """Version of KMS symmetric key"""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "version_id", b"version_id"]) -> None: ...

global___KMSKey = KMSKey



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.loadtesting.agent.v1 import job_service_pb2 as yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/loadtesting/agent/v1/job_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class JobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ClaimStatus = channel.unary_unary(
                '/yandex.cloud.loadtesting.agent.v1.JobService/ClaimStatus',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusResponse.FromString,
                _registered_method=True)
        self.Get = channel.unary_unary(
                '/yandex.cloud.loadtesting.agent.v1.JobService/Get',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.Job.FromString,
                _registered_method=True)
        self.GetSignal = channel.unary_unary(
                '/yandex.cloud.loadtesting.agent.v1.JobService/GetSignal',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalResponse.FromString,
                _registered_method=True)
        self.GetTransientFile = channel.unary_unary(
                '/yandex.cloud.loadtesting.agent.v1.JobService/GetTransientFile',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobTransientFile.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.File.FromString,
                _registered_method=True)


class JobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ClaimStatus(self, request, context):
        """Claims status for the specified job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the job for the specified agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSignal(self, request, context):
        """Returns the signal for the specified job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransientFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ClaimStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ClaimStatus,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.Job.SerializeToString,
            ),
            'GetSignal': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSignal,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalResponse.SerializeToString,
            ),
            'GetTransientFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransientFile,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobTransientFile.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.File.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.loadtesting.agent.v1.JobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.loadtesting.agent.v1.JobService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class JobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ClaimStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.agent.v1.JobService/ClaimStatus',
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.agent.v1.JobService/Get',
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.Job.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSignal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.agent.v1.JobService/GetSignal',
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransientFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.agent.v1.JobService/GetTransientFile',
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobTransientFile.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.File.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.operation.operation_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class OperationServiceStub:
    """A set of methods for managing operations for asynchronous API requests."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.operation.operation_service_pb2.GetOperationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Returns the specified Operation resource."""

    Cancel: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.operation.operation_service_pb2.CancelOperationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels the specified operation.

    Note that currently Object Storage API does not support cancelling operations.
    """

class OperationServiceAsyncStub:
    """A set of methods for managing operations for asynchronous API requests."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.operation.operation_service_pb2.GetOperationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Returns the specified Operation resource."""

    Cancel: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.operation.operation_service_pb2.CancelOperationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels the specified operation.

    Note that currently Object Storage API does not support cancelling operations.
    """

class OperationServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing operations for asynchronous API requests."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.operation.operation_service_pb2.GetOperationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Returns the specified Operation resource."""

    @abc.abstractmethod
    def Cancel(
        self,
        request: yandex.cloud.operation.operation_service_pb2.CancelOperationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Cancels the specified operation.

        Note that currently Object Storage API does not support cancelling operations.
        """

def add_OperationServiceServicer_to_server(servicer: OperationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.logging.v1.export_pb2
import yandex.cloud.logging.v1.export_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ExportServiceStub:
    """A set of methods for managing log exports."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Run: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.RunExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Run new logs export from log group to sink"""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.GetExportRequest,
        yandex.cloud.logging.v1.export_pb2.Export,
    ]
    """Returns the specified export.

    To get the list of all available exports, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.ListExportsRequest,
        yandex.cloud.logging.v1.export_service_pb2.ListExportsResponse,
    ]
    """Retrieves the list of exports in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.CreateExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a export in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.UpdateExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified export."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.DeleteExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified export."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.ListExportOperationsRequest,
        yandex.cloud.logging.v1.export_service_pb2.ListExportOperationsResponse,
    ]
    """Lists operations for the specified export."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified export."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified export."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified export."""

class ExportServiceAsyncStub:
    """A set of methods for managing log exports."""

    Run: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.RunExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Run new logs export from log group to sink"""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.GetExportRequest,
        yandex.cloud.logging.v1.export_pb2.Export,
    ]
    """Returns the specified export.

    To get the list of all available exports, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.ListExportsRequest,
        yandex.cloud.logging.v1.export_service_pb2.ListExportsResponse,
    ]
    """Retrieves the list of exports in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.CreateExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a export in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.UpdateExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified export."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.DeleteExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified export."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.logging.v1.export_service_pb2.ListExportOperationsRequest,
        yandex.cloud.logging.v1.export_service_pb2.ListExportOperationsResponse,
    ]
    """Lists operations for the specified export."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified export."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified export."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified export."""

class ExportServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing log exports."""

    @abc.abstractmethod
    def Run(
        self,
        request: yandex.cloud.logging.v1.export_service_pb2.RunExportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Run new logs export from log group to sink"""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.logging.v1.export_service_pb2.GetExportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.logging.v1.export_pb2.Export, collections.abc.Awaitable[yandex.cloud.logging.v1.export_pb2.Export]]:
        """Returns the specified export.

        To get the list of all available exports, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.logging.v1.export_service_pb2.ListExportsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.logging.v1.export_service_pb2.ListExportsResponse, collections.abc.Awaitable[yandex.cloud.logging.v1.export_service_pb2.ListExportsResponse]]:
        """Retrieves the list of exports in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.logging.v1.export_service_pb2.CreateExportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a export in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.logging.v1.export_service_pb2.UpdateExportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified export."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.logging.v1.export_service_pb2.DeleteExportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified export."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.logging.v1.export_service_pb2.ListExportOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.logging.v1.export_service_pb2.ListExportOperationsResponse, collections.abc.Awaitable[yandex.cloud.logging.v1.export_service_pb2.ListExportOperationsResponse]]:
        """Lists operations for the specified export."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified export."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified export."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified export."""

def add_ExportServiceServicer_to_server(servicer: ExportServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/operation/operation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/operation/operation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/operation/operation.proto\x12\x16yandex.cloud.operation\x1a\x19google/protobuf/any.proto\x1a\x17google/rpc/status.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb0\x02\n\tOperation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12/\n\x0bmodified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64one\x18\x06 \x01(\x08\x12&\n\x08metadata\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\x12#\n\x05\x65rror\x18\x08 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x12(\n\x08response\x18\t \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x08\n\x06resultBb\n\x1ayandex.cloud.api.operationZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/operation;operationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.operation.operation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.operationZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/operation;operation'
  _globals['_OPERATION']._serialized_start=152
  _globals['_OPERATION']._serialized_end=456
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/host_type_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/host_type_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.compute.v1 import host_type_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_host__type__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/compute/v1/host_type_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a\'yandex/cloud/compute/v1/host_type.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x12GetHostTypeRequest\x12\"\n\x0chost_type_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"T\n\x14ListHostTypesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"g\n\x15ListHostTypesResponse\x12\x35\n\nhost_types\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.HostType\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9e\x02\n\x0fHostTypeService\x12\x83\x01\n\x03Get\x12+.yandex.cloud.compute.v1.GetHostTypeRequest\x1a!.yandex.cloud.compute.v1.HostType\",\x82\xd3\xe4\x93\x02&\x12$/compute/v1/hostTypes/{host_type_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.compute.v1.ListHostTypesRequest\x1a..yandex.cloud.compute.v1.ListHostTypesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/compute/v1/hostTypesBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.host_type_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_GETHOSTTYPEREQUEST'].fields_by_name['host_type_id']._loaded_options = None
  _globals['_GETHOSTTYPEREQUEST'].fields_by_name['host_type_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTHOSTTYPESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTHOSTTYPESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTHOSTTYPESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTHOSTTYPESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_HOSTTYPESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_HOSTTYPESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/compute/v1/hostTypes/{host_type_id}'
  _globals['_HOSTTYPESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_HOSTTYPESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/compute/v1/hostTypes'
  _globals['_GETHOSTTYPEREQUEST']._serialized_start=178
  _globals['_GETHOSTTYPEREQUEST']._serialized_end=234
  _globals['_LISTHOSTTYPESREQUEST']._serialized_start=236
  _globals['_LISTHOSTTYPESREQUEST']._serialized_end=320
  _globals['_LISTHOSTTYPESRESPONSE']._serialized_start=322
  _globals['_LISTHOSTTYPESRESPONSE']._serialized_end=425
  _globals['_HOSTTYPESERVICE']._serialized_start=428
  _globals['_HOSTTYPESERVICE']._serialized_end=714
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v2/docker_image_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v2/docker_image_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/datasphere/v2/docker_image_service.proto\x12\x1ayandex.cloud.datasphere.v2\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"_\n\x1a\x41\x63tivateDockerImageRequest\x12 \n\nproject_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\tdocker_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xc2\x01\n\x12\x44ockerImageService\x12\xab\x01\n\x08\x41\x63tivate\x12\x36.yandex.cloud.datasphere.v2.ActivateDockerImageRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\x17\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02#\"\x1e/datasphere/v2/docker/activate:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.docker_image_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _globals['_ACTIVATEDOCKERIMAGEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ACTIVATEDOCKERIMAGEREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ACTIVATEDOCKERIMAGEREQUEST'].fields_by_name['docker_id']._loaded_options = None
  _globals['_ACTIVATEDOCKERIMAGEREQUEST'].fields_by_name['docker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DOCKERIMAGESERVICE'].methods_by_name['Activate']._loaded_options = None
  _globals['_DOCKERIMAGESERVICE'].methods_by_name['Activate']._serialized_options = b'\262\322*\027\022\025google.protobuf.Empty\202\323\344\223\002#\"\036/datasphere/v2/docker/activate:\001*'
  _globals['_ACTIVATEDOCKERIMAGEREQUEST']._serialized_start=220
  _globals['_ACTIVATEDOCKERIMAGEREQUEST']._serialized_end=315
  _globals['_DOCKERIMAGESERVICE']._serialized_start=318
  _globals['_DOCKERIMAGESERVICE']._serialized_end=512
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AutoTranscode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AutoTranscodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AutoTranscode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AUTO_TRANSCODE_UNSPECIFIED: _AutoTranscode.ValueType  # 0
    """Unspecified auto transcoding value."""
    ENABLE: _AutoTranscode.ValueType  # 1
    """Enable auto transcoding."""
    DISABLE: _AutoTranscode.ValueType  # 2
    """Disable auto transcoding."""

class AutoTranscode(_AutoTranscode, metaclass=_AutoTranscodeEnumTypeWrapper): ...

AUTO_TRANSCODE_UNSPECIFIED: AutoTranscode.ValueType  # 0
"""Unspecified auto transcoding value."""
ENABLE: AutoTranscode.ValueType  # 1
"""Enable auto transcoding."""
DISABLE: AutoTranscode.ValueType  # 2
"""Disable auto transcoding."""
global___AutoTranscode = AutoTranscode

@typing.final
class Video(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _VideoStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VideoStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Video._VideoStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VIDEO_STATUS_UNSPECIFIED: Video._VideoStatus.ValueType  # 0
        """Video status unspecified."""
        WAIT_UPLOADING: Video._VideoStatus.ValueType  # 1
        """Waiting for all the bytes to be loaded."""
        UPLOADED: Video._VideoStatus.ValueType  # 2
        """Fully uploaded, ready to be transcoded."""
        PROCESSING: Video._VideoStatus.ValueType  # 4
        """Video is being processed."""
        READY: Video._VideoStatus.ValueType  # 5
        """Successfully processed and ready for use."""
        ERROR: Video._VideoStatus.ValueType  # 7
        """Video processing has failed."""

    class VideoStatus(_VideoStatus, metaclass=_VideoStatusEnumTypeWrapper): ...
    VIDEO_STATUS_UNSPECIFIED: Video.VideoStatus.ValueType  # 0
    """Video status unspecified."""
    WAIT_UPLOADING: Video.VideoStatus.ValueType  # 1
    """Waiting for all the bytes to be loaded."""
    UPLOADED: Video.VideoStatus.ValueType  # 2
    """Fully uploaded, ready to be transcoded."""
    PROCESSING: Video.VideoStatus.ValueType  # 4
    """Video is being processed."""
    READY: Video.VideoStatus.ValueType  # 5
    """Successfully processed and ready for use."""
    ERROR: Video.VideoStatus.ValueType  # 7
    """Video processing has failed."""

    class _VisibilityStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VisibilityStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Video._VisibilityStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VISIBILITY_STATUS_UNSPECIFIED: Video._VisibilityStatus.ValueType  # 0
        """Visibility status unspecified."""
        PUBLISHED: Video._VisibilityStatus.ValueType  # 1
        """Video published and available for public viewing."""
        UNPUBLISHED: Video._VisibilityStatus.ValueType  # 2
        """Video unpublished, available only to administrators."""

    class VisibilityStatus(_VisibilityStatus, metaclass=_VisibilityStatusEnumTypeWrapper): ...
    VISIBILITY_STATUS_UNSPECIFIED: Video.VisibilityStatus.ValueType  # 0
    """Visibility status unspecified."""
    PUBLISHED: Video.VisibilityStatus.ValueType  # 1
    """Video published and available for public viewing."""
    UNPUBLISHED: Video.VisibilityStatus.ValueType  # 2
    """Video unpublished, available only to administrators."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    VISIBILITY_STATUS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    AUTO_TRANSCODE_FIELD_NUMBER: builtins.int
    ENABLE_AD_FIELD_NUMBER: builtins.int
    SUBTITLE_IDS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    TUSD_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the video."""
    channel_id: builtins.str
    """ID of the channel where the video was created."""
    title: builtins.str
    """Video title displayed to users."""
    description: builtins.str
    """Detailed description of the video."""
    thumbnail_id: builtins.str
    """ID of the video's thumbnail image."""
    status: global___Video.VideoStatus.ValueType
    """Video status."""
    error_message: builtins.str
    """Error message describing the reason for video processing failure, if any."""
    visibility_status: global___Video.VisibilityStatus.ValueType
    """Visibility status of the video."""
    auto_transcode: global___AutoTranscode.ValueType
    """Auto-transcoding setting.
    Set ENABLE to automatically initiate transcoding after upload,
    or DISABLE for manual initiation via the Transcode() method.
    """
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Video duration. Optional, may be empty until the transcoding result is ready."""

    @property
    def enable_ad(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enable advertisement for this video.
        Default: true.
        Set explicitly to false to disable advertisements for a specific video.
        """

    @property
    def subtitle_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of IDs defining the active subtitles for the video."""

    @property
    def features(self) -> global___VideoFeatures:
        """Additional video processing features and their results."""

    @property
    def tusd(self) -> global___VideoTUSDSource:
        """Upload video using the tus protocol."""

    @property
    def public_access(self) -> global___VideoPublicAccessRights:
        """Publicly accessible video available for viewing by anyone with the direct link.
        No additional authorization or access control is applied.
        """

    @property
    def sign_url_access(self) -> global___VideoSignURLAccessRights:
        """Checking access rights using url's signature."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when video was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of last video update."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        status: global___Video.VideoStatus.ValueType = ...,
        error_message: builtins.str = ...,
        visibility_status: global___Video.VisibilityStatus.ValueType = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        auto_transcode: global___AutoTranscode.ValueType = ...,
        enable_ad: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        subtitle_ids: collections.abc.Iterable[builtins.str] | None = ...,
        features: global___VideoFeatures | None = ...,
        tusd: global___VideoTUSDSource | None = ...,
        public_access: global___VideoPublicAccessRights | None = ...,
        sign_url_access: global___VideoSignURLAccessRights | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "created_at", b"created_at", "duration", b"duration", "enable_ad", b"enable_ad", "features", b"features", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "source", b"source", "tusd", b"tusd", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auto_transcode", b"auto_transcode", "channel_id", b"channel_id", "created_at", b"created_at", "description", b"description", "duration", b"duration", "enable_ad", b"enable_ad", "error_message", b"error_message", "features", b"features", "id", b"id", "labels", b"labels", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "source", b"source", "status", b"status", "subtitle_ids", b"subtitle_ids", "thumbnail_id", b"thumbnail_id", "title", b"title", "tusd", b"tusd", "updated_at", b"updated_at", "visibility_status", b"visibility_status"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["tusd"] | None: ...

global___Video = Video

@typing.final
class VideoTUSDSource(google.protobuf.message.Message):
    """Video upload source via tus protocol."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL for uploading video via the tus protocol."""
    file_size: builtins.int
    """Size of the uploaded file, in bytes."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        file_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_size", b"file_size", "url", b"url"]) -> None: ...

global___VideoTUSDSource = VideoTUSDSource

@typing.final
class VideoPublicAccessRights(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoPublicAccessRights = VideoPublicAccessRights

@typing.final
class VideoSignURLAccessRights(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoSignURLAccessRights = VideoSignURLAccessRights

@typing.final
class VideoFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _FeatureResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FeatureResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VideoFeatures._FeatureResult.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FEATURE_RESULT_UNSPECIFIED: VideoFeatures._FeatureResult.ValueType  # 0
        NOT_REQUESTED: VideoFeatures._FeatureResult.ValueType  # 1
        """Feature has not been requested."""
        PROCESSING: VideoFeatures._FeatureResult.ValueType  # 2
        """Feature is being processed."""
        SUCCESS: VideoFeatures._FeatureResult.ValueType  # 3
        """Feature processing completed successfully."""
        FAILED: VideoFeatures._FeatureResult.ValueType  # 4
        """Feature processing has failed."""

    class FeatureResult(_FeatureResult, metaclass=_FeatureResultEnumTypeWrapper): ...
    FEATURE_RESULT_UNSPECIFIED: VideoFeatures.FeatureResult.ValueType  # 0
    NOT_REQUESTED: VideoFeatures.FeatureResult.ValueType  # 1
    """Feature has not been requested."""
    PROCESSING: VideoFeatures.FeatureResult.ValueType  # 2
    """Feature is being processed."""
    SUCCESS: VideoFeatures.FeatureResult.ValueType  # 3
    """Feature processing completed successfully."""
    FAILED: VideoFeatures.FeatureResult.ValueType  # 4
    """Feature processing has failed."""

    @typing.final
    class Summary(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class SummaryURL(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            URL_FIELD_NUMBER: builtins.int
            TRACK_INDEX_FIELD_NUMBER: builtins.int
            SRC_LANG_FIELD_NUMBER: builtins.int
            url: builtins.str
            track_index: builtins.int
            """Input audio track index (one-based)."""
            src_lang: builtins.str
            """Source track language (three-letter code according to ISO 639-2/T, ISO 639-2/B, or ISO 639-3).
            Either provided in transcoding settings earlier or automatically deduced.
            """
            def __init__(
                self,
                *,
                url: builtins.str = ...,
                track_index: builtins.int = ...,
                src_lang: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["src_lang", b"src_lang", "track_index", b"track_index", "url", b"url"]) -> None: ...

        RESULT_FIELD_NUMBER: builtins.int
        URLS_FIELD_NUMBER: builtins.int
        result: global___VideoFeatures.FeatureResult.ValueType
        @property
        def urls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoFeatures.Summary.SummaryURL]: ...
        def __init__(
            self,
            *,
            result: global___VideoFeatures.FeatureResult.ValueType = ...,
            urls: collections.abc.Iterable[global___VideoFeatures.Summary.SummaryURL] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["result", b"result", "urls", b"urls"]) -> None: ...

    SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def summary(self) -> global___VideoFeatures.Summary:
        """Summarization result."""

    def __init__(
        self,
        *,
        summary: global___VideoFeatures.Summary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["summary", b"summary"]) -> None: ...

global___VideoFeatures = VideoFeatures



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Filesystem(google.protobuf.message.Message):
    """A filesystem resource.
    For details about the concept, see [documentation](/docs/compute/concepts/filesystem).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Filesystem._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Filesystem._Status.ValueType  # 0
        CREATING: Filesystem._Status.ValueType  # 1
        """The filesystem is being created."""
        READY: Filesystem._Status.ValueType  # 2
        """The filesystem is ready to use."""
        ERROR: Filesystem._Status.ValueType  # 3
        """The filesystem encountered a problem and cannot operate."""
        DELETING: Filesystem._Status.ValueType  # 4
        """The filesystem is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Filesystem.Status.ValueType  # 0
    CREATING: Filesystem.Status.ValueType  # 1
    """The filesystem is being created."""
    READY: Filesystem.Status.ValueType  # 2
    """The filesystem is ready to use."""
    ERROR: Filesystem.Status.ValueType  # 3
    """The filesystem encountered a problem and cannot operate."""
    DELETING: Filesystem.Status.ValueType  # 4
    """The filesystem is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the filesystem. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the filesystem belongs to."""
    name: builtins.str
    """Name of the filesystem. The name is unique within the folder."""
    description: builtins.str
    """Description of the filesystem."""
    type_id: builtins.str
    """ID of the filesystem type.

    To get a list of available filesystem types, make a [yandex.cloud.compute.v1.DiskTypeService.List] request.
    """
    zone_id: builtins.str
    """ID of the availability zone where the filesystem resides.

    A filesystem can be attached only to instances residing in the same availability zone.
    """
    size: builtins.int
    """Size of the filesystem, specified in bytes."""
    block_size: builtins.int
    """Block size used for the filesystem, specified in bytes."""
    status: global___Filesystem.Status.ValueType
    """Current status of the filesystem."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Filesystem labels as `key:value` pairs.
        For details about the concept, see [documentation](/docs/overview/concepts/services#labels).
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        size: builtins.int = ...,
        block_size: builtins.int = ...,
        status: global___Filesystem.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["block_size", b"block_size", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "size", b"size", "status", b"status", "type_id", b"type_id", "zone_id", b"zone_id"]) -> None: ...

global___Filesystem = Filesystem



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_BY_ID_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the secret."""
    project_id: builtins.str
    """ID of the project."""
    name: builtins.str
    """Name of the secret. 1-63 characters long."""
    description: builtins.str
    """Description of the secret. 0-256 characters long."""
    created_by_id: builtins.str
    """ID of the user who created secret."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when secret was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the secret."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of last secret update."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_by_id: builtins.str = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by_id", b"created_by_id", "description", b"description", "id", b"id", "labels", b"labels", "name", b"name", "project_id", b"project_id", "updated_at", b"updated_at"]) -> None: ...

global___Secret = Secret

@typing.final
class DecryptedSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """Content of the secret."""
    @property
    def secret(self) -> global___Secret: ...
    def __init__(
        self,
        *,
        secret: global___Secret | None = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "secret", b"secret"]) -> None: ...

global___DecryptedSecret = DecryptedSecret



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/workflows/v1/workflow.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/workflows/v1/workflow.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/serverless/workflows/v1/workflow.proto\x12$yandex.cloud.serverless.workflows.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\xec\x04\n\x08Workflow\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12R\n\rspecification\x18\x03 \x01(\x0b\x32;.yandex.cloud.serverless.workflows.v1.WorkflowSpecification\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12J\n\x06labels\x18\x07 \x03(\x0b\x32:.yandex.cloud.serverless.workflows.v1.Workflow.LabelsEntry\x12\x45\n\x06status\x18\x08 \x01(\x0e\x32\x35.yandex.cloud.serverless.workflows.v1.Workflow.Status\x12\x45\n\x0blog_options\x18\t \x01(\x0b\x32\x30.yandex.cloud.serverless.workflows.v1.LogOptions\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12\x1a\n\x12service_account_id\x18\x0b \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\"\xc3\x03\n\x0fWorkflowPreview\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12Q\n\x06labels\x18\x06 \x03(\x0b\x32\x41.yandex.cloud.serverless.workflows.v1.WorkflowPreview.LabelsEntry\x12\x45\n\x06status\x18\x07 \x01(\x0e\x32\x35.yandex.cloud.serverless.workflows.v1.Workflow.Status\x12\x45\n\x0blog_options\x18\x08 \x01(\x0b\x32\x30.yandex.cloud.serverless.workflows.v1.LogOptions\x12\x12\n\nnetwork_id\x18\t \x01(\t\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x15WorkflowSpecification\x12\x13\n\tspec_yaml\x18\x01 \x01(\tH\x00\x42\x0c\n\x04spec\x12\x04\xc0\xc1\x31\x01\"\x96\x01\n\nLogOptions\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12\x16\n\x0clog_group_id\x18\x02 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x03 \x01(\tH\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stinationB~\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflowsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.workflows.v1.workflow_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflows'
  _globals['_WORKFLOW_LABELSENTRY']._loaded_options = None
  _globals['_WORKFLOW_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_WORKFLOWPREVIEW_LABELSENTRY']._loaded_options = None
  _globals['_WORKFLOWPREVIEW_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_WORKFLOWSPECIFICATION'].oneofs_by_name['spec']._loaded_options = None
  _globals['_WORKFLOWSPECIFICATION'].oneofs_by_name['spec']._serialized_options = b'\300\3011\001'
  _globals['_WORKFLOW']._serialized_start=199
  _globals['_WORKFLOW']._serialized_end=819
  _globals['_WORKFLOW_LABELSENTRY']._serialized_start=675
  _globals['_WORKFLOW_LABELSENTRY']._serialized_end=720
  _globals['_WORKFLOW_STATUS']._serialized_start=722
  _globals['_WORKFLOW_STATUS']._serialized_end=819
  _globals['_WORKFLOWPREVIEW']._serialized_start=822
  _globals['_WORKFLOWPREVIEW']._serialized_end=1273
  _globals['_WORKFLOWPREVIEW_LABELSENTRY']._serialized_start=675
  _globals['_WORKFLOWPREVIEW_LABELSENTRY']._serialized_end=720
  _globals['_WORKFLOWSPECIFICATION']._serialized_start=1275
  _globals['_WORKFLOWSPECIFICATION']._serialized_end=1333
  _globals['_LOGOPTIONS']._serialized_start=1336
  _globals['_LOGOPTIONS']._serialized_end=1486
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.cloudrouter.v1 import routing_instance_pb2 as yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2
from yandex.cloud.cloudrouter.v1 import routing_instance_service_pb2 as yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/cloudrouter/v1/routing_instance_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class RoutingInstanceServiceStub(object):
    """A set of methods for managing RoutingInstance resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/Get',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.FromString,
                _registered_method=True)
        self.GetByVpcNetworkId = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/GetByVpcNetworkId',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceByVpcNetworkIdRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.FromString,
                _registered_method=True)
        self.GetByCicPrivateConnectionId = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/GetByCicPrivateConnectionId',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/List',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstancesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstancesResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/Create',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.CreateRoutingInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/Update',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpdateRoutingInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpsertPrefixes = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/UpsertPrefixes',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpsertPrefixesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.RemovePrefixes = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/RemovePrefixes',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.RemovePrefixesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.MovePrefix = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/MovePrefix',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.MovePrefixRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdatePrefixMask = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/UpdatePrefixMask',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpdatePrefixMaskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.AddPrivateConnection = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/AddPrivateConnection',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.AddPrivateConnectionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.RemovePrivateConnection = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/RemovePrivateConnection',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.RemovePrivateConnectionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/Delete',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.DeleteRoutingInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstanceOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstanceOperationsResponse.FromString,
                _registered_method=True)


class RoutingInstanceServiceServicer(object):
    """A set of methods for managing RoutingInstance resources.
    """

    def Get(self, request, context):
        """Returns the specified RoutingInstance resource.

        To get the list of available RoutingInstance resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByVpcNetworkId(self, request, context):
        """Returns the RoutingInstance resource by vpcNetworkId

        To get the list of available RoutingInstance resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByCicPrivateConnectionId(self, request, context):
        """Returns the RoutingInstance resource by cicPrivateConnectionId

        To get the list of available RoutingInstance resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of RoutingInstance resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a RoutingInstance resource in the specified folder using the data specified in the request.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates a RoutingInstance resource using the data specified in the request.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertPrefixes(self, request, context):
        """Upserts specified prefixes to a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePrefixes(self, request, context):
        """Removes specified prefixes from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MovePrefix(self, request, context):
        """Moves the specified prefix between availability zones of the RoutingInstance.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePrefixMask(self, request, context):
        """Removes specified PrivateConnection from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPrivateConnection(self, request, context):
        """Adds specified PrivateConnection to a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePrivateConnection(self, request, context):
        """Removes specified PrivateConnection from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified RoutingInstance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RoutingInstanceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.SerializeToString,
            ),
            'GetByVpcNetworkId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByVpcNetworkId,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceByVpcNetworkIdRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.SerializeToString,
            ),
            'GetByCicPrivateConnectionId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByCicPrivateConnectionId,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstancesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstancesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.CreateRoutingInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpdateRoutingInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpsertPrefixes': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertPrefixes,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpsertPrefixesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemovePrefixes': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePrefixes,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.RemovePrefixesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'MovePrefix': grpc.unary_unary_rpc_method_handler(
                    servicer.MovePrefix,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.MovePrefixRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdatePrefixMask': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePrefixMask,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpdatePrefixMaskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddPrivateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPrivateConnection,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.AddPrivateConnectionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemovePrivateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePrivateConnection,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.RemovePrivateConnectionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.DeleteRoutingInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstanceOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstanceOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.cloudrouter.v1.RoutingInstanceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.cloudrouter.v1.RoutingInstanceService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class RoutingInstanceService(object):
    """A set of methods for managing RoutingInstance resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/Get',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetByVpcNetworkId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/GetByVpcNetworkId',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceByVpcNetworkIdRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetByCicPrivateConnectionId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/GetByCicPrivateConnectionId',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2.RoutingInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/List',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstancesRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstancesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/Create',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.CreateRoutingInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/Update',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpdateRoutingInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpsertPrefixes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/UpsertPrefixes',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpsertPrefixesRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemovePrefixes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/RemovePrefixes',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.RemovePrefixesRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MovePrefix(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/MovePrefix',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.MovePrefixRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdatePrefixMask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/UpdatePrefixMask',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.UpdatePrefixMaskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddPrivateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/AddPrivateConnection',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.AddPrivateConnectionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemovePrivateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/RemovePrivateConnection',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.RemovePrivateConnectionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/Delete',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.DeleteRoutingInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.cloudrouter.v1.RoutingInstanceService/ListOperations',
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstanceOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__service__pb2.ListRoutingInstanceOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Database(google.protobuf.message.Message):
    """An SQL Server database.

    For more information, see the [Concepts](/docs/managed-sqlserver/concepts) section of the documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the database."""
    cluster_id: builtins.str
    """ID of the SQL Server cluster that the database belongs to."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___Database = Database

@typing.final
class DatabaseSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the database."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___DatabaseSpec = DatabaseSpec



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.ai.stt.v3 import stt_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2
from yandex.cloud.ai.stt.v3 import stt_service_pb2 as yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/stt/v3/stt_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class RecognizerStub(object):
    """A set of methods for voice recognition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RecognizeStreaming = channel.stream_stream(
                '/speechkit.stt.v3.Recognizer/RecognizeStreaming',
                request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.FromString,
                _registered_method=True)


class RecognizerServicer(object):
    """A set of methods for voice recognition.
    """

    def RecognizeStreaming(self, request_iterator, context):
        """Expects audio in real-time
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RecognizerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RecognizeStreaming': grpc.stream_stream_rpc_method_handler(
                    servicer.RecognizeStreaming,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'speechkit.stt.v3.Recognizer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('speechkit.stt.v3.Recognizer', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Recognizer(object):
    """A set of methods for voice recognition.
    """

    @staticmethod
    def RecognizeStreaming(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/speechkit.stt.v3.Recognizer/RecognizeStreaming',
            yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class AsyncRecognizerStub(object):
    """A set of methods for async voice recognition.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RecognizeFile = channel.unary_unary(
                '/speechkit.stt.v3.AsyncRecognizer/RecognizeFile',
                request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.RecognizeFileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GetRecognition = channel.unary_stream(
                '/speechkit.stt.v3.AsyncRecognizer/GetRecognition',
                request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__service__pb2.GetRecognitionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.FromString,
                _registered_method=True)
        self.DeleteRecognition = channel.unary_unary(
                '/speechkit.stt.v3.AsyncRecognizer/DeleteRecognition',
                request_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.DeleteRecognitionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                _registered_method=True)


class AsyncRecognizerServicer(object):
    """A set of methods for async voice recognition.
    """

    def RecognizeFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecognition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRecognition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AsyncRecognizerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RecognizeFile': grpc.unary_unary_rpc_method_handler(
                    servicer.RecognizeFile,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.RecognizeFileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetRecognition': grpc.unary_stream_rpc_method_handler(
                    servicer.GetRecognition,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__service__pb2.GetRecognitionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.SerializeToString,
            ),
            'DeleteRecognition': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRecognition,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.DeleteRecognitionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'speechkit.stt.v3.AsyncRecognizer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('speechkit.stt.v3.AsyncRecognizer', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AsyncRecognizer(object):
    """A set of methods for async voice recognition.
    """

    @staticmethod
    def RecognizeFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/speechkit.stt.v3.AsyncRecognizer/RecognizeFile',
            yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.RecognizeFileRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRecognition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/speechkit.stt.v3.AsyncRecognizer/GetRecognition',
            yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__service__pb2.GetRecognitionRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.StreamingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteRecognition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/speechkit.stt.v3.AsyncRecognizer/DeleteRecognition',
            yandex_dot_cloud_dot_ai_dot_stt_dot_v3_dot_stt__pb2.DeleteRecognitionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/mdb/greenplum/v1/user.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1dyandex/cloud/validation.proto\"\x90\x01\n\x04User\x12;\n\x04name\x18\x01 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31\x1d^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\x8a\xc8\x31\x04\x31-63\x12\x1b\n\x08password\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05\x36-200\x12.\n\x0eresource_group\x18\x03 \x01(\tB\x16\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_USER'].fields_by_name['name']._loaded_options = None
  _globals['_USER'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\212\3101\0041-63'
  _globals['_USER'].fields_by_name['password']._loaded_options = None
  _globals['_USER'].fields_by_name['password']._serialized_options = b'\212\3101\0056-200'
  _globals['_USER'].fields_by_name['resource_group']._loaded_options = None
  _globals['_USER'].fields_by_name['resource_group']._serialized_options = b'\362\3071\022^[^\\|/*?.,;\"\'<>]+$'
  _globals['_USER']._serialized_start=107
  _globals['_USER']._serialized_end=251
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.trino.v1.catalog_pb2
import yandex.cloud.trino.v1.catalog_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class CatalogServiceStub:
    """A set of methods for managing Trino Cluster Catalog resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.GetCatalogRequest,
        yandex.cloud.trino.v1.catalog_pb2.Catalog,
    ]
    """Returns the specified Trino Catalog resource."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.ListCatalogsRequest,
        yandex.cloud.trino.v1.catalog_service_pb2.ListCatalogsResponse,
    ]
    """Retrieves a list of Trino Catalog resources."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.CreateCatalogRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new Trino Catalog."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.UpdateCatalogRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified Trino Catalog."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.DeleteCatalogRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified Trino Catalog."""

class CatalogServiceAsyncStub:
    """A set of methods for managing Trino Cluster Catalog resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.GetCatalogRequest,
        yandex.cloud.trino.v1.catalog_pb2.Catalog,
    ]
    """Returns the specified Trino Catalog resource."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.ListCatalogsRequest,
        yandex.cloud.trino.v1.catalog_service_pb2.ListCatalogsResponse,
    ]
    """Retrieves a list of Trino Catalog resources."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.CreateCatalogRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new Trino Catalog."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.UpdateCatalogRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified Trino Catalog."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.trino.v1.catalog_service_pb2.DeleteCatalogRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified Trino Catalog."""

class CatalogServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Trino Cluster Catalog resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.trino.v1.catalog_service_pb2.GetCatalogRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.trino.v1.catalog_pb2.Catalog, collections.abc.Awaitable[yandex.cloud.trino.v1.catalog_pb2.Catalog]]:
        """Returns the specified Trino Catalog resource."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.trino.v1.catalog_service_pb2.ListCatalogsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.trino.v1.catalog_service_pb2.ListCatalogsResponse, collections.abc.Awaitable[yandex.cloud.trino.v1.catalog_service_pb2.ListCatalogsResponse]]:
        """Retrieves a list of Trino Catalog resources."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.trino.v1.catalog_service_pb2.CreateCatalogRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new Trino Catalog."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.trino.v1.catalog_service_pb2.UpdateCatalogRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified Trino Catalog."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.trino.v1.catalog_service_pb2.DeleteCatalogRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified Trino Catalog."""

def add_CatalogServiceServicer_to_server(servicer: CatalogServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
